==> mingw-w64-cargo-tauri-2.2.7-1.src.tar.zst: tauri-tauri-cli-v2.2.7/crates/tauri/permissions/path/autogenerated/reference.md <==
## Default Permission

Default permissions for the plugin.

- `allow-resolve-directory`
- `allow-resolve`
- `allow-normalize`
- `allow-join`
- `allow-dirname`
- `allow-extname`
- `allow-basename`
- `allow-is-absolute`

## Permission Table

<table>
<tr>
<th>Identifier</th>
<th>Description</th>
</tr>


<tr>
<td>

`core:path:allow-basename`

</td>
<td>

Enables the basename command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-basename`

</td>
<td>

Denies the basename command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-dirname`

</td>
<td>

Enables the dirname command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-dirname`

</td>
<td>

Denies the dirname command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-extname`

</td>
<td>

Enables the extname command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-extname`

</td>
<td>

Denies the extname command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-is-absolute`

</td>
<td>

Enables the is_absolute command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-is-absolute`

</td>
<td>

Denies the is_absolute command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-join`

</td>
<td>

Enables the join command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-join`

</td>
<td>

Denies the join command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-normalize`

</td>
<td>

Enables the normalize command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-normalize`

</td>
<td>

Denies the normalize command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-resolve`

</td>
<td>

Enables the resolve command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-resolve`

</td>
<td>

Denies the resolve command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-resolve-directory`

</td>
<td>

Enables the resolve_directory command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-resolve-directory`

</td>
<td>

Denies the resolve_directory command without any pre-configured scope.

</td>
</tr>
</table>

==> mingw-w64-cargo-tauri-2.8.4-1.src.tar.zst: tauri-tauri-cli-v2.8.4/crates/tauri/permissions/path/autogenerated/reference.md <==
## Default Permission

Default permissions for the plugin, which enables all commands.

#### This default permission set includes the following:

- `allow-resolve-directory`
- `allow-resolve`
- `allow-normalize`
- `allow-join`
- `allow-dirname`
- `allow-extname`
- `allow-basename`
- `allow-is-absolute`

## Permission Table

<table>
<tr>
<th>Identifier</th>
<th>Description</th>
</tr>


<tr>
<td>

`core:path:allow-basename`

</td>
<td>

Enables the basename command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-basename`

</td>
<td>

Denies the basename command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-dirname`

</td>
<td>

Enables the dirname command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-dirname`

</td>
<td>

Denies the dirname command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-extname`

</td>
<td>

Enables the extname command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-extname`

</td>
<td>

Denies the extname command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-is-absolute`

</td>
<td>

Enables the is_absolute command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-is-absolute`

</td>
<td>

Denies the is_absolute command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-join`

</td>
<td>

Enables the join command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-join`

</td>
<td>

Denies the join command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-normalize`

</td>
<td>

Enables the normalize command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-normalize`

</td>
<td>

Denies the normalize command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-resolve`

</td>
<td>

Enables the resolve command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-resolve`

</td>
<td>

Denies the resolve command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:allow-resolve-directory`

</td>
<td>

Enables the resolve_directory command without any pre-configured scope.

</td>
</tr>

<tr>
<td>

`core:path:deny-resolve-directory`

</td>
<td>

Denies the resolve_directory command without any pre-configured scope.

</td>
</tr>
</table>
